@@ -633,7 +633,7 @@
 
 #' @title Check if the bands of all tiles of the cube are the same
 #' @name .cube_unique_bands
-#'
+#' @keywords internal
 #' @param  cube         input data cube
 #' @return TRUE/FALSE
 .cube_unique_bands <- function(cube) {
@@ -649,7 +649,7 @@
 }
 #' @title Check if bboxes of all tiles of the cube are the same
 #' @name .cube_unique_bbox
-#'
+#' @keywords internal
 #' @param  cube         input data cube
 #' @return TRUE/FALSE
 .cube_unique_bbox <- function(cube) {
@@ -694,7 +694,7 @@
 }
 #' @title Check if sizes of all tiles of the cube are the same
 #' @name .cube_unique_tile_size
-#'
+#' @keywords internal
 #' @param  cube         input data cube
 #' @return TRUE/FALSE
 .cube_unique_tile_size <- function(cube) {
@@ -716,7 +716,7 @@
 
 #' @title Check if timelines all tiles of the cube are the same
 #' @name .cube_unique_timeline
-#'
+#' @keywords internal
 #' @param  cube         input data cube
 #' @return TRUE/FALSE
 .cube_unique_timeline <- function(cube) {
@@ -1036,7 +1036,7 @@
 }
 
 #' @export
-.cube_token_generator.mspc_cube <- function(cube) {
+.cube_token_generator.mpc_cube <- function(cube) {
     file_info <- cube[["file_info"]][[1]]
     fi_paths <- file_info[["path"]]
 
@@ -1082,7 +1082,7 @@
 
     .check_that(
         !is.null(res_content),
-        msg = "invalid mspc token."
+        msg = "invalid mpc token."
     )
 
     token_parsed <- httr::parse_url(paste0("?", res_content[["token"]]))
