@@ -12,6 +12,8 @@
 #'  \item{SOM evaluate cluster: } {see \code{\link{plot.som_evaluate_cluster}}}
 #'  \item{classified time series: } {see \code{\link{plot.predicted}}}
 #'  \item{raster cube: }         {see \code{\link{plot.raster_cube}}}
+#'  \item{random forest model:} {see \code{\link{plot.rfor_model}}}
+#'  \item{xgboost model:} {see \code{\link{plot.xgb_model}}}
 #'  \item{torch ML model: } {see \code{\link{plot.torch_model}}}
 #'  \item{classification probabilities: }{see \code{\link{plot.probs_cube}}}
 #'  \item{model uncertainty: } {see \code{\link{plot.uncertainty_cube}}}
@@ -324,7 +326,7 @@ plot.raster_cube <- function(x, ...,
                              green = NULL,
                              blue = NULL,
                              tile = x$tile[[1]],
-                             date = sits_timeline(x)[1]) {
+                             date = NULL) {
     .check_chr_contains(
         x = x$tile,
         contains = tile,
@@ -375,17 +377,24 @@ plot.raster_cube <- function(x, ...,
 
     # select only one tile
     row <- dplyr::filter(x, .data[["tile"]] == !!tile)
-    # use only one date
-    date <- as.Date(date)
-    .check_that(
-        length(date) == 1,
-        msg = "plot handles one date at a time"
-    )
-    .check_that(
-        date %in% sits_timeline(row),
-        msg = "requested date is not part of the cube"
-    )
 
+    # if dates are not informed, show the first possible date
+    if (purrr::is_null(date))
+        date <- sits_timeline(row)[1]
+    else {
+        # use only one date
+        date <- as.Date(date)
+        .check_that(
+            length(date) == 1,
+            msg = "plot handles one date at a time"
+        )
+        # check if date is inside the timeline
+        tile_dates <- sits_timeline(row)
+        if (!date %in% tile_dates) {
+            idx_date <- which.min(abs(date - tile_dates))
+            date <- tile_dates[idx_date]
+        }
+    }
     # plot the selected tile
     # select the bands for the timeline
     bds_date <- dplyr::filter(.file_info(row), .data[["date"]] == !!date)
@@ -529,6 +538,8 @@ plot.probs_cube <- function(x, ...,
     # get the labels
     labels_cube <- sits_labels(x)
 
+    # resize to the [0..1] interval
+    stars_mosaic <- stars_mosaic * .config_get("raster_cube_scale_factor")
     # verify if label is not NULL
     if (!purrr::is_null(labels)) {
         # label is not null, then plot only the label
@@ -854,7 +865,43 @@ plot.classified_image <- function(x, y, ...,
     graphics::plot(g)
     return(invisible(g))
 }
+#' @title  Plot Random Forest  model
+#' @name   plot.rfor_model
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#'
+#' @description Plots the important variables in a random forest model.
+#'
+#'
+#' @param  x             Object of class "rf_model".
+#' @param  y             Ignored.
+#' @param  ...           Further specifications for \link{plot}.
+#' @return               A random forest object.
+#'
+#' @note
+#' Please refer to the sits documentation available in
+#' <https://e-sensing.github.io/sitsbook/> for detailed examples.
+#' @examples
+#' if (sits_run_examples()) {
+#'     # Retrieve the samples for Mato Grosso
+#'     # train a random forest model
+#'     rf_model <- sits_train(samples_modis_4bands,  ml_method = sits_rfor())
+#'     # plot the model
+#'     plot(rf_model)
+#' }
+#' @export
+#'
+plot.rfor_model <- function(x, y, ...){
+    # verifies if randomForestExplainer package is installed
+    .check_require_packages("randomForestExplainer")
+    # retrieve the random forest object from the enviroment
+    rf <- environment(x)$result_rfor
+    p <- randomForestExplainer::plot_min_depth_distribution(rf)
+    return(p)
+}
 
+
+
+#'
 #' @title  Plot confusion between clusters
 #' @name   plot.som_evaluate_cluster
 #' @author Lorena Santos \email{lorena.santos@@inpe.br}
@@ -999,7 +1046,41 @@ plot.som_map <- function(x, y, ..., type = "codes", band = 1) {
         ncol = 1
     )
 }
-
+#' @title  Plot XGB model
+#' @name   plot.xgb_model
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#'
+#' @description Plots the important variables in an extreme gradient boosting.
+#'
+#'
+#' @param  x             Object of class "xgb_model".
+#' @param  ...           Further specifications for \link{plot}.
+#' @param  n_trees       Number of trees to be plotted
+#' @return               A plot object.
+#'
+#' @note
+#' Please refer to the sits documentation available in
+#' <https://e-sensing.github.io/sitsbook/> for detailed examples.
+#' @examples
+#' if (sits_run_examples()) {
+#'     # Retrieve the samples for Mato Grosso
+#'     # train an extreme gradient boosting
+#'     xgb_model <- sits_train(samples_modis_4bands,
+#'            ml_method = sits_xgboost())
+#'     # plot the model
+#'     plot(xgb_model)
+#' }
+#' @export
+#'
+plot.xgb_model <- function(x, ..., n_trees = 3){
+    # verifies if DiagrammeR package is installed
+    .check_require_packages("DiagrammeR")
+    # retrieve the XGB object from the enviroment
+    xgb <- environment(x)$model_xgb
+    # plot the trees
+    p <- xgboost::xgb.plot.tree(model = xgb, trees = seq_len(n_trees) - 1)
+    return(p)
+}
 #' @title  Plot Torch (deep learning) model
 #' @name   plot.torch_model
 #' @author Felipe Souza, \email{lipecaso@@gmail.com}
@@ -1607,7 +1688,19 @@ plot.torch_model <- function(x, y, ...) {
 #' "Machine learning-based global maps of ecological variables and the
 #' challenge of assessing them" Nature Communications, 13,2022.
 #' DOI: 10.1038/s41467-022-29838-9.
-#'
+#' @examples
+#' if (sits_run_examples()) {
+#'     # read a shapefile for the state of Mato Grosso, Brazil
+#'     mt_shp <- system.file("extdata/shapefiles/mato_grosso/mt.shp",
+#'         package = "sits"
+#'     )
+#'     # convert to an sf object
+#'     mt_sf <- sf::read_sf(mt_shp)
+#'     # calculate sample-to-sample and sample-to-prediction distances
+#'     distances <- sits_geo_dist(samples_modis_4bands, mt_sf)
+#'     # plot sample-to-sample and sample-to-prediction distances
+#'     plot(distances)
+#' }
 #' @export
 #'
 plot.geo_distances <- function(x, y, ...) {
