@@ -4,7 +4,7 @@
 #'
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
-#'
+#' @author Alber Sanchez, \email{alber.ipia@@inpe.br}
 #'
 #' @param  cube              Probability data cube.
 #' @param  type              Method to measure uncertainty. See details.
@@ -222,7 +222,17 @@ sits_uncertainty.entropy <- function(cube, type = "entropy", ...,
 
         # if file exists skip it (resume feature)
         if (file.exists(out_file)) {
-            return(NULL)
+            if (all(.raster_bbox(.raster_open_rast(out_file))
+                    == sits_bbox(tile_new))) {
+                message(paste0(
+                    "Recovery mode: uncertainty image file found in '",
+                    dirname(out_file), "' directory. ",
+                    "(If you want a new uncertainty image, please ",
+                    "change the directory in the 'output_dir' or the ",
+                    "value of 'version' parameter)"
+                ))
+                return(NULL)
+            }
         }
 
         # overlapping pixels
@@ -249,12 +259,29 @@ sits_uncertainty.entropy <- function(cube, type = "entropy", ...,
             b <- .raster_open_rast(in_file)
 
             # crop adding overlaps
-            chunk <- .raster_crop(r_obj = b, block = block)
+            temp_chunk_file <- .create_chunk_file(
+                output_dir = output_dir,
+                pattern = "chunk_entrop_overlap_",
+                ext = ".tif"
+            )
+            chunk <- .raster_crop(
+                r_obj = b,
+                file = temp_chunk_file,
+                format = "GTiff",
+                data_type = .raster_data_type(
+                    .config_get("probs_cube_data_type")
+                ),
+                gdal_options = .config_gtiff_default_options(),
+                overwrite = TRUE,
+                block = block
+            )
+            # Delete temp file
+            on.exit(unlink(temp_chunk_file), add = TRUE)
 
             # process it
             raster_out <- .do_entropy(chunk = chunk)
 
-            # create extent
+            # Create extent
             blk_no_overlap <- list(
                 first_row = block$crop_first_row,
                 nrows = block$crop_nrows,
@@ -262,18 +289,15 @@ sits_uncertainty.entropy <- function(cube, type = "entropy", ...,
                 ncols = block$crop_ncols
             )
 
-            # crop removing overlaps
-            raster_out <- .raster_crop(raster_out, block = blk_no_overlap)
-
-            # export to temp file
             block_file <- .smth_filename(
                 tile = tile_new,
                 output_dir = output_dir,
                 block = block
             )
 
-            # save chunk
-            .raster_write_rast(
+            # Save chunk
+            # Crop removing overlaps
+            .raster_crop(
                 r_obj = raster_out,
                 file = block_file,
                 format = "GTiff",
@@ -281,7 +305,8 @@ sits_uncertainty.entropy <- function(cube, type = "entropy", ...,
                     .config_get("probs_cube_data_type")
                 ),
                 gdal_options = .config_gtiff_default_options(),
-                overwrite = TRUE
+                overwrite = TRUE,
+                block = blk_no_overlap
             )
 
             return(block_file)
@@ -345,7 +370,8 @@ sits_uncertainty.entropy <- function(cube, type = "entropy", ...,
     # bind rows
     result_cube <- dplyr::bind_rows(result_cube)
 
-    class(result_cube) <- c("uncertainty_cube", class(cube))
+    class(result_cube) <- c("uncertainty_cube",
+                            setdiff(class(cube), "probs_cube"))
 
     return(result_cube)
 }
@@ -492,7 +518,17 @@ sits_uncertainty.least <- function(cube, type = "least", ...,
 
         # if file exists skip it (resume feature)
         if (file.exists(out_file)) {
-            return(NULL)
+            if (all(.raster_bbox(.raster_open_rast(out_file))
+                    == sits_bbox(tile_new))) {
+                message(paste0(
+                    "Recovery mode: uncertainty image file found in '",
+                    dirname(out_file), "' directory. ",
+                    "(If you want a new uncertainty image, please ",
+                    "change the directory in the 'output_dir' or the ",
+                    "value of 'version' parameter)"
+                ))
+                return(NULL)
+            }
         }
 
         # overlapping pixels
@@ -519,7 +555,24 @@ sits_uncertainty.least <- function(cube, type = "least", ...,
             b <- .raster_open_rast(in_file)
 
             # crop adding overlaps
-            chunk <- .raster_crop(r_obj = b, block = block)
+            temp_chunk_file <- .create_chunk_file(
+                output_dir = output_dir,
+                pattern = "chunk_least_overlap_",
+                ext = ".tif"
+            )
+            chunk <- .raster_crop(
+                r_obj = b,
+                file = temp_chunk_file,
+                format = "GTiff",
+                data_type = .raster_data_type(
+                    .config_get("probs_cube_data_type")
+                ),
+                gdal_options = .config_gtiff_default_options(),
+                overwrite = TRUE,
+                block = block
+            )
+            # Delete temp file
+            on.exit(unlink(temp_chunk_file), add = TRUE)
 
             # process it
             raster_out <- .do_least(chunk = chunk)
@@ -532,18 +585,15 @@ sits_uncertainty.least <- function(cube, type = "least", ...,
                 ncols = block$crop_ncols
             )
 
-            # crop removing overlaps
-            raster_out <- .raster_crop(raster_out, block = blk_no_overlap)
-
-            # export to temp file
             block_file <- .smth_filename(
                 tile = tile_new,
                 output_dir = output_dir,
                 block = block
             )
 
-            # save chunk
-            .raster_write_rast(
+            # Save chunk
+            # Crop removing overlaps
+            .raster_crop(
                 r_obj = raster_out,
                 file = block_file,
                 format = "GTiff",
@@ -551,7 +601,8 @@ sits_uncertainty.least <- function(cube, type = "least", ...,
                     .config_get("probs_cube_data_type")
                 ),
                 gdal_options = .config_gtiff_default_options(),
-                overwrite = TRUE
+                overwrite = TRUE,
+                block = blk_no_overlap
             )
 
             return(block_file)
@@ -615,7 +666,8 @@ sits_uncertainty.least <- function(cube, type = "least", ...,
     # bind rows
     result_cube <- dplyr::bind_rows(result_cube)
 
-    class(result_cube) <- c("uncertainty_cube", class(cube))
+    class(result_cube) <- c("uncertainty_cube",
+                            setdiff(class(cube), "probs_cube"))
 
     return(result_cube)
 }
@@ -762,7 +814,17 @@ sits_uncertainty.margin <- function(cube, type = "margin", ...,
 
         # if file exists skip it (resume feature)
         if (file.exists(out_file)) {
-            return(NULL)
+            if (all(.raster_bbox(.raster_open_rast(out_file))
+                    == sits_bbox(tile_new))) {
+                message(paste0(
+                    "Recovery mode: uncertainty image file found in '",
+                    dirname(out_file), "' directory. ",
+                    "(If you want a new uncertainty image, please ",
+                    "change the directory in the 'output_dir' or the ",
+                    "value of 'version' parameter)"
+                ))
+                return(NULL)
+            }
         }
 
         # overlapping pixels
@@ -789,7 +851,24 @@ sits_uncertainty.margin <- function(cube, type = "margin", ...,
             b <- .raster_open_rast(in_file)
 
             # crop adding overlaps
-            chunk <- .raster_crop(r_obj = b, block = block)
+            temp_chunk_file <- .create_chunk_file(
+                output_dir = output_dir,
+                pattern = "chunk_margin_overlap_",
+                ext = ".tif"
+            )
+            chunk <- .raster_crop(
+                r_obj = b,
+                file = temp_chunk_file,
+                format = "GTiff",
+                data_type = .raster_data_type(
+                    .config_get("probs_cube_data_type")
+                ),
+                gdal_options = .config_gtiff_default_options(),
+                overwrite = TRUE,
+                block = block
+            )
+            # Delete temp file
+            on.exit(unlink(temp_chunk_file), add = TRUE)
 
             # process it
             raster_out <- .do_margin(chunk = chunk)
@@ -802,18 +881,15 @@ sits_uncertainty.margin <- function(cube, type = "margin", ...,
                 ncols = block$crop_ncols
             )
 
-            # crop removing overlaps
-            raster_out <- .raster_crop(raster_out, block = blk_no_overlap)
-
-            # export to temp file
             block_file <- .smth_filename(
                 tile = tile_new,
                 output_dir = output_dir,
                 block = block
             )
 
-            # save chunk
-            .raster_write_rast(
+            # Save chunk
+            # Crop removing overlaps
+            .raster_crop(
                 r_obj = raster_out,
                 file = block_file,
                 format = "GTiff",
@@ -821,7 +897,8 @@ sits_uncertainty.margin <- function(cube, type = "margin", ...,
                     .config_get("probs_cube_data_type")
                 ),
                 gdal_options = .config_gtiff_default_options(),
-                overwrite = TRUE
+                overwrite = TRUE,
+                block = blk_no_overlap
             )
 
             return(block_file)
@@ -885,7 +962,8 @@ sits_uncertainty.margin <- function(cube, type = "margin", ...,
     # bind rows
     result_cube <- dplyr::bind_rows(result_cube)
 
-    class(result_cube) <- c("uncertainty_cube", class(cube))
+    class(result_cube) <- c("uncertainty_cube",
+                            setdiff(class(cube), "probs_cube"))
 
     return(result_cube)
 }
@@ -1032,7 +1110,17 @@ sits_uncertainty.ratio <- function(cube, type = "ratio", ...,
 
         # if file exists skip it (resume feature)
         if (file.exists(out_file)) {
-            return(NULL)
+            if (all(.raster_bbox(.raster_open_rast(out_file))
+                    == sits_bbox(tile_new))) {
+                message(paste0(
+                    "Recovery mode: uncertainty image file found in '",
+                    dirname(out_file), "' directory. ",
+                    "(If you want a new uncertainty image, please ",
+                    "change the directory in the 'output_dir' or the ",
+                    "value of 'version' parameter)"
+                ))
+                return(NULL)
+            }
         }
 
         # overlapping pixels
@@ -1059,7 +1147,24 @@ sits_uncertainty.ratio <- function(cube, type = "ratio", ...,
             b <- .raster_open_rast(in_file)
 
             # crop adding overlaps
-            chunk <- .raster_crop(r_obj = b, block = block)
+            temp_chunk_file <- .create_chunk_file(
+                output_dir = output_dir,
+                pattern = "chunk_ratio_overlap_",
+                ext = ".tif"
+            )
+            chunk <- .raster_crop(
+                r_obj = b,
+                file = temp_chunk_file,
+                format = "GTiff",
+                data_type = .raster_data_type(
+                    .config_get("probs_cube_data_type")
+                ),
+                gdal_options = .config_gtiff_default_options(),
+                overwrite = TRUE,
+                block = block
+            )
+            # Delete temp file
+            on.exit(unlink(temp_chunk_file), add = TRUE)
 
             # process it
             raster_out <- .do_ratio(chunk = chunk)
@@ -1072,18 +1177,15 @@ sits_uncertainty.ratio <- function(cube, type = "ratio", ...,
                 ncols = block$crop_ncols
             )
 
-            # crop removing overlaps
-            raster_out <- .raster_crop(raster_out, block = blk_no_overlap)
-
-            # export to temp file
             block_file <- .smth_filename(
                 tile = tile_new,
                 output_dir = output_dir,
                 block = block
             )
 
-            # save chunk
-            .raster_write_rast(
+            # Save chunk
+            # Crop removing overlaps
+            .raster_crop(
                 r_obj = raster_out,
                 file = block_file,
                 format = "GTiff",
@@ -1091,7 +1193,8 @@ sits_uncertainty.ratio <- function(cube, type = "ratio", ...,
                     .config_get("probs_cube_data_type")
                 ),
                 gdal_options = .config_gtiff_default_options(),
-                overwrite = TRUE
+                overwrite = TRUE,
+                block = blk_no_overlap
             )
 
             return(block_file)
@@ -1155,7 +1258,8 @@ sits_uncertainty.ratio <- function(cube, type = "ratio", ...,
     # bind rows
     result_cube <- dplyr::bind_rows(result_cube)
 
-    class(result_cube) <- c("uncertainty_cube", class(cube))
+    class(result_cube) <- c("uncertainty_cube",
+                            setdiff(class(cube), "probs_cube"))
 
     return(result_cube)
 }
