@@ -32,7 +32,7 @@ test_that("Reading a raster cube", {
 })
 
 test_that("Creating cubes from BDC", {
-    testthat::skip_on_cran()
+
 
     # check "BDC_ACCESS_KEY" - mandatory one per user
     bdc_access_key <- Sys.getenv("BDC_ACCESS_KEY")
@@ -84,7 +84,7 @@ test_that("Creating cubes from BDC", {
 })
 
 test_that("Creating cubes from BDC - based on ROI with shapefile", {
-    testthat::skip_on_cran()
+
 
     # check "BDC_ACCESS_KEY" - mandatory one per user
     bdc_access_key <- Sys.getenv("BDC_ACCESS_KEY")
@@ -140,7 +140,7 @@ test_that("Creating cubes from BDC - based on ROI with shapefile", {
 })
 
 test_that("Creating cubes from BDC - invalid roi", {
-    testthat::skip_on_cran()
+
 
     # check "BDC_ACCESS_KEY" - mandatory one per user
     bdc_access_key <- Sys.getenv("BDC_ACCESS_KEY")
@@ -179,7 +179,7 @@ test_that("Creating cubes from BDC - invalid roi", {
 })
 
 test_that("Creating cubes from DEA", {
-    testthat::skip_on_cran()
+
 
     dea_cube <- tryCatch(
         {
@@ -215,7 +215,7 @@ test_that("Creating cubes from DEA", {
 })
 
 test_that("Creating cubes from DEA - error using tiles", {
-    testthat::skip_on_cran()
+
 
     expect_error(
         dea_cube <-
@@ -231,7 +231,6 @@ test_that("Creating cubes from DEA - error using tiles", {
     )
 })
 
-
 test_that("Regularizing cubes from AWS, and extracting samples from them", {
     s2_cube_open <- tryCatch(
         {
@@ -305,11 +304,7 @@ test_that("Regularizing cubes from AWS, and extracting samples from them", {
     expect_equal(sits_timeline(ts), sits_timeline(rg_cube))
 })
 
-
-
 test_that("Creating cubes from USGS", {
-    testthat::skip_on_cran()
-
     # check "AWS_ACCESS_KEY_ID" - mandatory one per user
     aws_access_key_id <- Sys.getenv("AWS_ACCESS_KEY_ID")
 
@@ -396,14 +391,14 @@ test_that("Creating cubes from USGS", {
     expect_equal(usgs_cube_2$xmin[[1]], .raster_xmin(r), tolerance = 1)
 })
 
-test_that("Creating Sentinel cubes from MSPC", {
-    testthat::skip_on_cran()
+test_that("Creating Sentinel cubes from MPC", {
+
 
     s2_cube <- tryCatch(
         {
             sits_cube(
-                source = "MSPC",
-                collection = "sentinel-2-l2a",
+                source = "MPC",
+                collection = "SENTINEL-2-L2A",
                 tiles = "20LKP",
                 bands = c("B05", "CLOUD"),
                 start_date = as.Date("2018-07-18"),
@@ -417,7 +412,7 @@ test_that("Creating Sentinel cubes from MSPC", {
 
     testthat::skip_if(
         purrr::is_null(s2_cube),
-        "MSPC is not accessible"
+        "MPC is not accessible"
     )
 
     expect_true(all(sits_bands(s2_cube) %in% c("B05", "CLOUD")))
@@ -432,8 +427,8 @@ test_that("Creating Sentinel cubes from MSPC", {
     expect_equal(s2_cube$xmin[[1]], .raster_xmin(r), tolerance = 1)
 })
 
-test_that("Creating Sentinel cubes from MSPC with ROI", {
-    testthat::skip_on_cran()
+test_that("Creating Sentinel cubes from MPC with ROI", {
+
 
     shp_file <- system.file("extdata/shapefiles/df_bsb/df_bsb.shp",
         package = "sits"
@@ -443,8 +438,8 @@ test_that("Creating Sentinel cubes from MSPC with ROI", {
     s2_cube <- tryCatch(
         {
             sits_cube(
-                source = "MSPC",
-                collection = "sentinel-2-l2a",
+                source = "MPC",
+                collection = "SENTINEL-2-L2A",
                 roi = sf_bsb,
                 bands = c("B05", "CLOUD"),
                 start_date = as.Date("2018-07-18"),
@@ -456,7 +451,7 @@ test_that("Creating Sentinel cubes from MSPC with ROI", {
         }
     )
 
-    testthat::skip_if(purrr::is_null(s2_cube), "MSPC is not accessible")
+    testthat::skip_if(purrr::is_null(s2_cube), "MPC is not accessible")
 
     expect_true(all(sits_bands(s2_cube) %in% c("B05", "CLOUD")))
 
@@ -480,23 +475,22 @@ test_that("Creating Sentinel cubes from MSPC with ROI", {
     )
 })
 
-test_that("Creating Landsat cubes from MSPC", {
-    testthat::skip_on_cran()
+test_that("Creating Landsat cubes from MPC", {
 
-    l8_cube <- tryCatch(
+    shp_file <- system.file("extdata/shapefiles/df_bsb/df_bsb.shp",
+                            package = "sits"
+    )
+    sf_bsb <- sf::read_sf(shp_file)
+
+    landsat_cube <- tryCatch(
         {
             sits_cube(
-                source = "MSPC",
-                collection = "landsat-8-c2-l2",
-                roi = c(
-                    "lon_min" = 17.379,
-                    "lat_min" = 1.1573,
-                    "lon_max" = 17.410,
-                    "lat_max" = 1.1910
-                ),
-                bands = c("B03", "CLOUD"),
-                start_date = as.Date("2019-07-18"),
-                end_date = as.Date("2019-10-23")
+                source = "MPC",
+                collection = "LANDSAT-C2-L2",
+                roi = sf_bsb,
+                bands = c("NIR08", "CLOUD"),
+                start_date = as.Date("2008-07-18"),
+                end_date = as.Date("2008-10-23")
             )
         },
         error = function(e) {
@@ -504,65 +498,68 @@ test_that("Creating Landsat cubes from MSPC", {
         }
     )
 
-    testthat::skip_if(purrr::is_null(l8_cube), "MSPC is not accessible")
+    testthat::skip_if(purrr::is_null(landsat_cube), "MPC is not accessible")
 
-    expect_true(all(sits_bands(l8_cube) %in% c("B03", "CLOUD")))
-    expect_false(.cube_is_regular(l8_cube))
-    expect_equal(class(.file_info_xres(l8_cube)), "numeric")
+    expect_true(all(sits_bands(landsat_cube) %in% c("NIR08", "CLOUD")))
+    expect_false(.cube_is_regular(landsat_cube))
+    expect_equal(class(.file_info_xres(landsat_cube[1,])), "numeric")
+    expect_true(any(grepl("LT05", landsat_cube$file_info[[1]]$fid)))
+    expect_true(any(grepl("LE07", landsat_cube$file_info[[1]]$fid)))
 
-    file_info <- l8_cube$file_info[[1]]
+    file_info <- landsat_cube$file_info[[1]]
     r <- .raster_open_rast(file_info$path[[1]])
 
-    expect_equal(l8_cube$xmax[[1]], .raster_xmax(r), tolerance = 1)
-    expect_equal(l8_cube$xmin[[1]], .raster_xmin(r), tolerance = 1)
+    expect_equal(landsat_cube$xmax[[1]], .raster_xmax(r), tolerance = 1)
+    expect_equal(landsat_cube$xmin[[1]], .raster_xmin(r), tolerance = 1)
 
     output_dir <- paste0(tempdir(), "/images")
     if (!dir.exists(output_dir)) {
         dir.create(output_dir)
     }
 
-    rg_l8 <- sits_regularize(
-        cube        = l8_cube,
+    rg_landsat <- sits_regularize(
+        cube        = landsat_cube,
         output_dir  = output_dir,
-        res         = 330,
+        res         = 240,
         period      = "P30D",
-        multicores  = 1
+        multicores  = 4
     )
 
-    size <- .cube_size(rg_l8)
+    size <- .cube_size(rg_landsat[1,])
 
-    expect_equal(size[["nrows"]], 704)
-    expect_equal(size[["ncols"]], 685)
+    expect_equal(size[["nrows"]], 856)
+    expect_equal(size[["ncols"]], 967)
 
-    expect_true(.cube_is_regular(rg_l8))
+    expect_true(.cube_is_regular(rg_landsat))
 
-    l8_cube_tile <- tryCatch(
+    l5_cube <- tryCatch(
         {
             sits_cube(
-                source = "MSPC",
-                collection = "landsat-8-c2-l2",
-                bands = c("B04", "CLOUD"),
-                tiles = "223067",
-                start_date = "2019-01-01",
-                end_date = "2019-10-28"
+                source = "MPC",
+                collection = "LANDSAT-C2-L2",
+                platform = "LANDSAT-5",
+                roi = sf_bsb,
+                bands = c("NIR08", "CLOUD"),
+                start_date = as.Date("2008-07-18"),
+                end_date = as.Date("2008-10-23")
             )
         },
         error = function(e) {
             return(NULL)
         }
     )
+    expect_true(any(grepl("LT05", l5_cube$file_info[[1]]$fid)))
+    expect_false(any(grepl("LE07", l5_cube$file_info[[1]]$fid)))
 
-    testthat::skip_if(
-        purrr::is_null(l8_cube_tile),
-        "MSPC is not accessible"
+    expect_error(sits_cube(
+                source = "MPC",
+                collection = "LANDSAT-C2-L2",
+                bands = c("NIR08", "CLOUD"),
+                tiles = "220071",
+                start_date = "2019-01-01",
+                end_date = "2019-10-28"
+            )
     )
-    bbox <- sits_bbox(l8_cube_tile)
-    expect_lt(bbox["xmax"], 760000)
-    expect_lt(bbox["ymax"], -1000000)
-
-    file_info <- l8_cube_tile$file_info[[1]]
-    r_obj <- sits:::.raster_open_rast(file_info$path[[1]])
-    expect_equal(nrow(r_obj), file_info[1, ]$nrows)
 })
 
 test_that("Creating a raster stack cube with BDC band names", {
