@@ -28,6 +28,40 @@ test_that("Reading a LAT/LONG from RASTER", {
     expect_true(length(sits_timeline(point_ndvi)) == 23)
 })
 
+test_that("Reading a LAT/LONG from RASTER with crs parameter", {
+    data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
+    raster_cube <- tryCatch(
+        {
+            sits_cube(
+                source = "BDC",
+                collection = "MOD13Q1-6",
+                data_dir = data_dir,
+                delim = "_",
+                parse_info = c("X1", "X2", "tile", "band", "date")
+            )
+        },
+        error = function(e) {
+            return(NULL)
+        }
+    )
+
+    testthat::skip_if(purrr::is_null(raster_cube),
+                      message = "LOCAL cube was not found"
+    )
+
+    samples <- tibble::tibble(longitude = 4821005, latitude = 10025310)
+
+    point_ndvi <- sits_get_data(
+        cube = raster_cube,
+        samples = samples,
+        crs = "+proj=aea +lat_0=-12 +lon_0=-54 +lat_1=-2 +lat_2=-22 +x_0=5000000 +y_0=10000000 +ellps=GRS80 +units=m +no_defs "
+    )
+
+    expect_equal(names(point_ndvi)[1], "longitude")
+    expect_true(ncol(sits_time_series(point_ndvi)) == 2)
+    expect_true(length(sits_timeline(point_ndvi)) == 23)
+})
+
 test_that("Reading a CSV file from RASTER", {
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     raster_cube <- tryCatch(
@@ -81,6 +115,61 @@ test_that("Reading a CSV file from RASTER", {
     expect_true(length(sits_timeline(points_df)) == 23)
 })
 
+test_that("Reading a CSV file from RASTER with crs parameter", {
+    data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
+    raster_cube <- tryCatch(
+        {
+            sits_cube(
+                source = "BDC",
+                collection = "MOD13Q1-6",
+                data_dir = data_dir,
+                delim = "_",
+                parse_info = c("X1", "X2", "tile", "band", "date")
+            )
+        },
+        error = function(e) {
+            return(NULL)
+        }
+    )
+
+    testthat::skip_if(purrr::is_null(raster_cube),
+                      message = "LOCAL cube was not found"
+    )
+
+    df_csv <- utils::read.csv(
+        system.file("extdata/samples/samples_sinop_crop.csv", package = "sits"),
+        stringsAsFactors = FALSE
+    )
+
+    class(df_csv) <- c("sits", class(df_csv))
+    df_sf <- sits_as_sf(data = df_csv, crs = 4326)
+    df_sf_reproj <- sf::st_transform(
+        x = df_sf,
+        crs = "+proj=aea +lat_0=-12 +lon_0=-54 +lat_1=-2 +lat_2=-22 +x_0=5000000 +y_0=10000000 +ellps=GRS80 +units=m +no_defs "
+    )
+
+    df_sf_reproj[, c("longitude", "latitude")] <-
+        sf::st_coordinates(df_sf_reproj)
+    path_samples_repr <- tempfile(fileext = ".csv")
+    utils::write.csv(
+        x = sf::st_drop_geometry(df_sf_reproj),
+        file = path_samples_repr
+    )
+
+    points_df <- sits_get_data(
+        raster_cube,
+        samples = path_samples_repr,
+        output_dir = tempdir(),
+        crs = "+proj=aea +lat_0=-12 +lon_0=-54 +lat_1=-2 +lat_2=-22 +x_0=5000000 +y_0=10000000 +ellps=GRS80 +units=m +no_defs "
+    )
+
+    expect_true("Forest" %in% sits_labels(points_df))
+    expect_equal(names(points_df)[1], "longitude")
+    expect_equal(length(names(points_df)), 7)
+    expect_true(ncol(sits_time_series(points_df)) == 2)
+    expect_true(length(sits_timeline(points_df)) == 23)
+})
+
 test_that("Reading a SHP file from RASTER", {
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     raster_cube <- tryCatch(
@@ -195,7 +284,39 @@ test_that("Reading a SHP file from RASTER", {
     )
 
     expect_equal(object = nrow(points_shp_avg), expected = 3)
-    expect_equal(object = sits_labels(points_shp_avg), expected = "NoClass")
+    expect_equal(
+        object = sits_labels(points_shp_avg),
+        expected = c("a", "b", "c")
+    )
+
+    temp_shp_no_label <- dplyr::select(temp_shp, -.data[["label"]])
+    points_shp_no_label <- sits_get_data(raster_cube,
+                                    samples = temp_shp_no_label,
+                                    pol_avg = TRUE,
+                                    pol_id = "id",
+                                    output_dir = tempdir()
+    )
+
+    expect_equal(object = nrow(points_shp_no_label), expected = 3)
+    expect_equal(
+        object = sits_labels(points_shp_no_label),
+        expected = "NoClass"
+    )
+
+    temp_shp_label_attr <- dplyr::rename(temp_shp, label_2 = .data[["label"]])
+    points_shp_label_attr <- sits_get_data(raster_cube,
+                                           samples = temp_shp_label_attr,
+                                           pol_avg = TRUE,
+                                           pol_id = "id",
+                                           label_attr = "label_2",
+                                           output_dir = tempdir()
+    )
+
+    expect_equal(object = nrow(points_shp_label_attr), expected = 3)
+    expect_equal(
+        object = sits_labels(points_shp_label_attr),
+        expected = c("a", "b", "c")
+    )
 
 
     expect_error(
@@ -217,7 +338,7 @@ test_that("Reading a SHP file from RASTER", {
 })
 
 test_that("Test reading shapefile from BDC", {
-    testthat::skip_on_cran()
+
 
     # check "BDC_ACCESS_KEY" - mandatory one per user
     bdc_access_key <- Sys.getenv("BDC_ACCESS_KEY")
