@@ -1,5 +1,5 @@
 test_that("All", {
-    reproj <- .sits_proj_from_latlong(-10, -20, 4326)
+    reproj <- .sits_proj_from_latlong(-10, -20, crs = 4326)
 
     expect_equal(as.numeric(reproj[1, 1]), -10)
     expect_equal(as.numeric(reproj[1, 2]), -20)
